﻿// Print Tool Moves in a STEP-NC Process using C#
// ========================================
//
// This C# project calls the STEP-NC API using the .NET interface.  It
// prints all tool moves in a machining program.
//
// You can find more examples and other documentation at:
//
//      http://www.steptools.com/support/
//

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using STEPNCLib;

namespace cursor_moves_cs
{
    class Program
    {
	static void Main(string[] args)
	{
	    Finder finder = new Finder();
	    Adaptive ctl = new Adaptive();

	    // Read a STEP-NC file
	    finder.Open238("C:/Program Files (x86)/STEP Tools/STEP-NC Machine/examples/boxy_renton_signed.stpnc");

	    // Start traversing the process within the file.   Uses the active data from finder.
	    ctl.StartProject();

	    // The Move event is the only one selected by default
	    while (ctl.Next() != Adaptive.CtlEvent.DONE)
	    {
		switch (ctl.GetActiveType())
		{
		    case Adaptive.CtlType.MOVE:
			Console.WriteLine("LINEAR MOVE");
			printend(ctl, ctl.GetMoveEnd());
			break;
		    case Adaptive.CtlType.MOVE_ARC:
			Console.WriteLine("ARC MOVE");
			printarc(ctl, ctl.GetMoveArc());
			printend(ctl, ctl.GetMoveEnd());
			break;
		    case Adaptive.CtlType.MOVE_HELIX:
			Console.WriteLine("HELIX MOVE");
			printarc(ctl, ctl.GetMoveArc());
			printend(ctl, ctl.GetMoveEnd());
			break;
		}
	    }
	}


	static void printend(Adaptive ctl, uint p)
	{
	    double a, b, c;
	    ctl.GetPosXYZ(out a, out b, out c, p);
	    Console.Write("  END: XYZ: {0:0.0####} {1:0.0####} {2:0.0####}", a, b, c);

	    ctl.GetPosDirZ(out a, out b, out c, p);
	    Console.Write("  ZDIR: {0:0.0####} {1:0.0####} {2:0.0####}", a, b, c);
	    Console.WriteLine();
	}

	// Print arc center, radius, and direction for an arc move
	//
	static void printarc(Adaptive ctl, uint p)
	{
	    double a, b, c;
	    ctl.GetPosXYZ(out a, out b, out c, p);
	    Console.Write("  END: XYZ: {0:0.0####} {1:0.0####} {2:0.0####}", a, b, c);
	    if (ctl.GetArcIsCW(p))
		Console.Write("  ARC: CW");
	    else
		Console.Write("  ARC: CCW");

	    ctl.GetArcCenter(out a, out b, out c, p);
	    Console.Write("  END: XYZ: {0:0.0####} {1:0.0####} {2:0.0####}", a, b, c);

	    Console.Write("  RADIUS: {0:0.0####}", ctl.GetArcRadius(p));
	    Console.Write("  ANGLE: {0:0.0####}", ctl.GetArcAngle(p));
	    Console.WriteLine();
	}

    }
}
